AdwTextField class

Inheritance

Constructors

AdwTextField({Key? key, TextEditingController? controller, TextInputType? keyboardType, void onChanged(String)?, IconData? icon, IconData? prefixIcon, ValueChanged<String>? onSubmitted, String? initialValue, bool autofocus = false})
const

Properties

autofocus → bool
Will automatically focus on this field when it's visible
final
controller → TextEditingController?
The controller for the field
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
The suffix icon for this field
final
initialValue → String?
The initial value (if any) for this field
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
Keyboard Type for this field
final
onChanged → void Function(String)?
Runs when value is changed from this field
final
onSubmitted → void Function(String)?
To be run when you submit this field using Enter key
final
prefixIcon → IconData?
The prefix icon for this field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited