AdwViewSwitcher class

Inheritance

Constructors

AdwViewSwitcher({Key? key, required List<ViewSwitcherData> tabs, required ValueChanged<int> onViewChanged, required int currentIndex, Color? badgeColor, ViewSwitcherPolicy? policy, @Deprecated('This parameter is no longer in use') double height = 55, @Deprecated('This field is now ignored. ' 'This feature was deprecated after v1.0.0-rc.2') bool? expanded, EdgeInsets? paddingIcon})
const

Properties

badgeColor → Color?
The color of the badge at the top right of the tab's icon
final
currentIndex → int
The current index of the selected view
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onViewChanged → ValueChanged<int>
Executed when the view switcher tab is changed
final
paddingIcon → EdgeInsets?
The Padding for the icon of the view switcher tab
final
policy → ViewSwitcherPolicy?
The Policy of this view switcher defaults to wide for desktop and narrow for mobile
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabs → List<ViewSwitcherData>
The tabs of this view switcher
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited