FlapOptions class

Constructors

FlapOptions({FoldPolicy foldPolicy = FoldPolicy.auto, FlapPosition flapPosition = FlapPosition.start, bool visible = true})
const

Properties

flapPosition → FlapPosition
The FlapPosition of this flap, defaults to start
final
foldPolicy → FoldPolicy
The FoldPolicy of this flap, defaults to auto
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible → bool
The visiblity of this flap, defaults to true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited